@@ -1,13 +1,12 @@
+use anyhow::anyhow;
+use async_trait::async_trait;
 use k8s_openapi::chrono::Utc;
 use kube::{
   core::DynamicObject,
   discovery::{ApiResource, Scope},
   Api, ResourceExt,
 };
-
-use anyhow::anyhow;
-use async_trait::async_trait;
-use tui::{
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -73,6 +72,9 @@ impl From<DynamicObject> for KubeDynamicResource {
 }
 
 impl KubeResource<DynamicObject> for KubeDynamicResource {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &DynamicObject {
     &self.k8s_obj
   }
@@ -182,6 +184,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
