@@ -1,7 +1,6 @@
-use k8s_openapi::{api::batch::v1::Job, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::batch::v1::Job, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -71,6 +70,9 @@ impl From<Job> for KubeJob {
 }
 
 impl KubeResource<Job> for KubeJob {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &Job {
     &self.k8s_obj
   }
@@ -134,6 +136,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
