@@ -1,7 +1,6 @@
-use k8s_openapi::{api::apps::v1::ReplicaSet, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::apps::v1::ReplicaSet, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -56,6 +55,9 @@ impl From<ReplicaSet> for KubeReplicaSet {
 }
 
 impl KubeResource<ReplicaSet> for KubeReplicaSet {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &ReplicaSet {
     &self.k8s_obj
   }
@@ -126,6 +128,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
