@@ -1,9 +1,8 @@
 use std::collections::BTreeMap;
 
-use k8s_openapi::{api::core::v1::Secret, chrono::Utc, ByteString};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::core::v1::Secret, chrono::Utc, ByteString};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -49,6 +48,9 @@ impl From<Secret> for KubeSecret {
 }
 
 impl KubeResource<Secret> for KubeSecret {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &Secret {
     &self.k8s_obj
   }
@@ -112,6 +114,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
