@@ -1,7 +1,6 @@
-use k8s_openapi::{api::core::v1::ServiceAccount, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::core::v1::ServiceAccount, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -46,6 +45,9 @@ impl From<ServiceAccount> for KubeSvcAcct {
 }
 
 impl KubeResource<ServiceAccount> for KubeSvcAcct {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &ServiceAccount {
     &self.k8s_obj
   }
@@ -112,6 +114,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
