@@ -1,10 +1,9 @@
+use async_trait::async_trait;
 use k8s_openapi::{
   api::core::v1::{Service, ServicePort},
   chrono::Utc,
 };
-
-use async_trait::async_trait;
-use tui::{
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -82,6 +81,9 @@ impl From<Service> for KubeSvc {
 }
 
 impl KubeResource<Service> for KubeSvc {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &Service {
     &self.k8s_obj
   }
@@ -156,6 +158,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
